﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using SimpleJSON;

public class FacebookScript : MonoBehaviour {

	void Awake()
	{
		// Initialisation du SDK Facebook
		FB.Init(onInitCompleted);
	}

	// Callback lorsque le sdk a fini de s'initialiser
	void onInitCompleted()
	{
		Debug.LogWarning("Initialization completed");
	}

	public void login()
	{
		// Permissions permettant d'acceder aux informations de l'utilisateur
		string permissions = "email,public_profile,publish_actions";
		
		// Si l'utilisateur n'est pas déjà connecté
		if (!FB.IsLoggedIn)
			FB.Login(permissions, loginCallback);
	}

	// Callback d'une connection
	void loginCallback(FBResult result)
	{
		if (string.IsNullOrEmpty(result.Error))
		{
			Debug.LogWarning("success : " + result.Text);
		}
		else
		{
			Debug.LogWarning("Error : " + result.Error);
		}
	}

	// Envoie une requete aux amis selectionnés
	public void inviteFriends()
	{
		FB.AppRequest(
			message : "come play with me",
			title: "Programmez !"
			);
	}

	public void sendScore(int score)
	{
		// Parametres d'envoie du score
		Dictionary<string,string> param = new Dictionary<string, string>();
		param.Add("score",score.ToString());

		// Utilisation de l'api pour envoyer le score
		FB.API("/me/scores",Facebook.HttpMethod.POST,sendScoreCallback,param);
	}

	void sendScoreCallback(FBResult result)
	{
		if (string.IsNullOrEmpty(result.Error))
		{
			Debug.LogWarning("Score Posted : " + result.Text);
		}
		else
		{
			Debug.LogWarning("Error : " + result.Error);
		}
	}

	public void getScore()
	{
		// Utilisation de l'api pour recevoir le score
		FB.API("/me/scores",Facebook.HttpMethod.GET,getScoreCallback);
	}

	void getScoreCallback(FBResult result)
	{
		if (string.IsNullOrEmpty(result.Error))
		{
			// le resultat est en json
			// On parse le json pour avoir seulement le score
			JSONNode json = JSONNode.Parse(result.Text);

			currentScore = int.Parse(json["data"][0]["score"]);
			Debug.LogWarning(json["data"][0]["score"]);
		}
		else
		{
			Debug.LogWarning("Error : " + result.Error);
		}
	}

	public void FeedStatus()
	{
		FB.Feed("","http://www.programmez.com/","Programmez","Caption","Description",
		        "http://mydomainename.com/img.jpg");
	}


	int currentScore = 0;
	string txt = "";
	void OnGUI()
	{
		GUILayout.Label("Intégration Facebook Unity 3D",GUILayout.MaxWidth(Screen.width));

		GUILayout.BeginHorizontal();

		if (FB.IsLoggedIn) {
			if (GUILayout.Button("Déconnexion",GUILayout.MaxWidth(Screen.width))) {
				FB.Logout();
			}
		}else{
			if (GUILayout.Button("Connexion",GUILayout.MaxWidth(Screen.width))) {
				login();
			}
		}

		GUILayout.EndHorizontal();

		if (!FB.IsLoggedIn)
			return;

		GUILayout.BeginHorizontal();

		if (GUILayout.Button("Invite Friends",GUILayout.MaxWidth(Screen.width))) {
			inviteFriends();
		}

		GUILayout.EndHorizontal();

		GUILayout.BeginHorizontal();
		
		if (GUILayout.Button("Poster message personnalisé",GUILayout.MaxWidth(Screen.width))) {
			FeedStatus();
		}
		
		GUILayout.EndHorizontal();

		GUILayout.BeginHorizontal();

		txt = GUILayout.TextField(txt,GUILayout.MaxWidth(Screen.width/2));

		if (GUILayout.Button("Envoyer mon Score",GUILayout.MaxWidth(Screen.width/2))) {
			try
			{
				sendScore(int.Parse(txt));
			}
			catch (UnityException e)
			{
				Debug.LogError(e);
			}
		}

		GUILayout.EndHorizontal();

		GUILayout.BeginHorizontal();

		GUILayout.Label(currentScore.ToString(),GUILayout.MaxWidth(Screen.width/2));
		
		if (GUILayout.Button("Recevoir mon Score",GUILayout.MaxWidth(Screen.width/2))) {
			getScore();
		}

		GUILayout.EndHorizontal();
	}
}
